NAME
Catalyst::Plugin::Statsd - Log Catalyst stats to statsd
SYNOPSIS
use Catalyst qw/
Statsd
-Stats=1
/;
use Net::Statsd::Tiny;
__PACKAGE__->config(
'psgi_middleware', [
Statsd => {
client => Net::Statsd::Tiny->new,
},
],
);
# (or you can specify the Statsd middleware in your
# application's PSGI file.)
DESCRIPTION
This plugin will log Catalyst timing statistics to statsd.
CONFIGURATION
__PACKAGE__->config(
'Plugin::Statsd' => {
disable_stats_report => 0,
},
);
disable_stats_report
Enabling stats will also log a table of statistics to the Catalyst
log. If you do not want this, then set disable_stats_report
to true.
Note that if you are modifying the log_stats method or using
another plugin that does this, then this may interfere with that if
you disable the stats report.
This defaults to
!$c->debug
RECENT CHANGES
Changes for version v0.10.0 (2026-05-09)
- Security
- The catalyst.sessionid metric is no longer logged unless Plack::Middleware::Statsd v0.9.0 or later is used with the secure_set_key. This is to avoid leaking session ids which might be usable as authentication tokens, CVE-2026-45180.
- Documentation
- Added a SECURITY CONSIDERATIONS section which documents how to use the secure set logging feature.
- Added a security policy.
- Updated copyright year.
- Updated author email due to issues with cpan.org email forwarding.
- Generate README with the UsefulReadme plugin.
- Remove the INSTALL file (since instructions are now in the README).
- Fixed typos.
- Toolchain
- Remove use of Dist::Zilla::ManifestSkip plugin.
- Stopped signing distributions, since Module::Signature is deprecated.
- Added doap.xml to the distribution.
- Tests
- Added more author tests.
See the Changes file for more details.
REQUIREMENTS
This module lists the following modules as runtime dependencies:
- Catalyst version 5.90123 or later
- Moose::Role
- POSIX
- Plack::Middleware::Statsd version v0.6.0 or later
- Ref::Util
- experimental
- namespace::autoclean
- perl version v5.20.0 or later
See the cpanfile file for the full list of prerequisites.
INSTALLATION
The latest version of this module (along with any dependencies) can be installed from CPAN with the cpan tool that is included with Perl:
cpan Catalyst::Plugin::Statsd
You can also extract the distribution archive and install this module (along with any dependencies):
cpan .
You can also install this module manually using the following commands:
perl Makefile.PL
make
make test
make install
If you are working with the source repository, then it may not have a Makefile.PL file. But you can use the Dist::Zilla tool in anger to build and install this module:
dzil build
dzil test
dzil install --install-command="cpan ."
For more information, see How to install CPAN modules.
SECURITY CONSIDERATIONS
If the "statsd_client" does not have a secure communications channel to the statsd server, then there is the risk that information such as IP addresses or session ids will be leaked.
Anything that needs to log information in a set that contains
personally identifiable information, authentication tokens or other
sensitive data should use the psgix.monitor.statsd_secure_set_add
function instead of the client's set_add method, for example:
if (my $secure_set_add = $c->req->env->{'psgix.monitor.statsd_secure_set_add'}) {
$secure_set_add->( $c->body_param->{name_of_sheep} );
}
SUPPORT
Only the latest version of this module will be supported.
This module requires Perl v5.20 or later. Future releases may only support Perl versions released in the last ten (10) years.
Please report any bugs or feature requests on the bugtracker website https://github.com/robrwo/CatalystX-Statsd/issues
When submitting a bug or request, please include a test-file or a patch to an existing test-file that illustrates the bug or desired feature.
If the bug you are reporting has security implications which make it inappropriate to send to a public issue tracker,
then see SECURITY.md for instructions how to report security vulnerabilities.
SOURCE
The development version is on github at https://github.com/robrwo/CatalystX-Statsd and may be cloned from https://github.com/robrwo/CatalystX-Statsd.git
AUTHOR
Robert Rothenberg perl@rhizomnic.com
The initial development of this module was sponsored by Science Photo Library https://www.sciencephoto.com.
CONTRIBUTOR
Slaven Rezić slaven@rezic.de
COPYRIGHT AND LICENSE
This software is Copyright (c) 2018-2026 by Robert Rothenberg.
This is free software, licensed under:
The Artistic License 2.0 (GPL Compatible)